@@ -14,12 +14,21 @@ import yaml
 from .mergers import merge
 
 
-ORDER = ['$ref', 'description', 'oneOf', 'anyOf', 'type', 'required', 'properties', "dependencies",
-         '$xor', '$or']
+ORDER = [
+    "$ref",
+    "description",
+    "oneOf",
+    "anyOf",
+    "type",
+    "required",
+    "properties",
+    "dependencies",
+    "$xor",
+    "$or",
+]
 
 
 class JsonSchemaLoader(object):
-
     def __init__(self, file, content=None):
         self.file = file
 
@@ -31,25 +40,28 @@ class JsonSchemaLoader(object):
             if pointer:
                 self.schema = resolve_pointer(self.schema, pointer)
 
-        self.version = self.schema.pop('$schema', '')
+        self.version = self.schema.pop("$schema", "")
         if self.version:
             try:
-                self.version = ' (%s)' % re.match(
-                    r'http://json-schema.org/(draft-\d\d)/schema#', self.version
-                ).groups()[0]
+                self.version = (
+                    " (%s)"
+                    % re.match(
+                        r"http://json-schema.org/(draft-\d\d)/schema#", self.version
+                    ).groups()[0]
+                )
             except AttributeError:
-                self.version = ''
+                self.version = ""
 
     def _load_internal(self, text):
         if text is None or len(text) == 0:
             raise RuntimeError(
                 "json-schema directive requires either filename, http url or inline content"
             )
-        self.schema = self.ordered_load('\n'.join(text))
+        self.schema = self.ordered_load("\n".join(text))
 
     def _load_external(self, file_or_url):
-        is_yaml = file_or_url.endswith('.yaml')
-        if file_or_url.startswith('http'):
+        is_yaml = file_or_url.endswith(".yaml")
+        if file_or_url.startswith("http"):
             text = requests.get(file_or_url)
             self.schema = self.ordered_load(text.content, is_yaml)
         else:
@@ -59,27 +71,32 @@ class JsonSchemaLoader(object):
                 self.schema = self.ordered_load(content, is_yaml)
 
     def _splitpointer(self, path):
-        val = path.split('#', 1)
+        val = path.split("#", 1)
         if len(val) == 1:
             val.append(None)
         return val
 
-    def ordered_load(self, stream, is_yaml = False):
+    def ordered_load(self, stream, is_yaml=False):
 
         # creates an ordered dictionary from a list of pairs
         def object_pairs_hook(pairs):
             d = {}
             for i, (key, value) in enumerate(pairs):
-                if key == '$ref':
+                if key == "$ref":
                     d.clear()
-                    d['$ref'] = value
-                    d.update(JsonSchemaLoader(
-                        os.path.join(
-                            os.path.dirname(stream if type(stream) == 'str' else self.file), value
-                        )
-                    ).schema)
+                    d["$ref"] = value
+                    d.update(
+                        JsonSchemaLoader(
+                            os.path.join(
+                                os.path.dirname(
+                                    stream if type(stream) == "str" else self.file
+                                ),
+                                value,
+                            )
+                        ).schema
+                    )
                     break
-                elif key in ['allOf', 'oneOf', 'anyOf']:
+                elif key in ["allOf", "oneOf", "anyOf"]:
                     # value is a list of dictionaries, they should be merged
                     for dd in value:
                         merge(d, dd, key)
@@ -107,4 +124,3 @@ class JsonSchemaLoader(object):
 
     def render(self):
         return json.dumps(self.schema, indent=2)
-
